package com.ruoyi.szxc.service;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcCsResponse;

/**
 * 场所负责人Service接口
 * 
 * @author hs
 * @date 2024-03-28
 */
public interface ISzxcCsResponseService 
{
    /**
     * 查询场所负责人
     * 
     * @param id 场所负责人主键
     * @return 场所负责人
     */
    public SzxcCsResponse selectSzxcCsResponseById(Long id);

    /**
     * 查询场所负责人列表
     * 
     * @param szxcCsResponse 场所负责人
     * @return 场所负责人集合
     */
    public List<SzxcCsResponse> selectSzxcCsResponseList(SzxcCsResponse szxcCsResponse);

    /**
     * 新增场所负责人
     * 
     * @param szxcCsResponse 场所负责人
     * @return 结果
     */
    public int insertSzxcCsResponse(SzxcCsResponse szxcCsResponse);

    /**
     * 修改场所负责人
     * 
     * @param szxcCsResponse 场所负责人
     * @return 结果
     */
    public int updateSzxcCsResponse(SzxcCsResponse szxcCsResponse);

    /**
     * 批量删除场所负责人
     * 
     * @param ids 需要删除的场所负责人主键集合
     * @return 结果
     */
    public int deleteSzxcCsResponseByIds(Long[] ids);

    /**
     * 删除场所负责人信息
     * 
     * @param id 场所负责人主键
     * @return 结果
     */
    public int deleteSzxcCsResponseById(Long id);
}
